:orphan:

.. _user_guide_index:

##########
User Guide
##########

.. note::

    **Making Open Source More Inclusive**

    Red Hat is committed to replacing problematic language in our code, documentation, and web properties. We are beginning with these four terms: master, slave, blacklist, and whitelist. We ask that you open an issue or pull request if you come upon a term that we have missed. For more details, see `our CTO Chris Wright's message <https://www.redhat.com/en/blog/making-open-source-more-inclusive-eradicating-problematic-language>`_.

Welcome to the Ansible User Guide!
This guide is now deprecated to improve navigation and organization.
You can find all the user guide content in the following sections:

* :ref:`inventory_guide_index`
* :ref:`command_guide_index`
* :ref:`playbook_guide_index`
* :ref:`vault_guide_index`
* :ref:`modules_plugins_index`
* :ref:`collections_index`
* :ref:`os_guide_index`
* :ref:`tips_tricks_index`
